@@ -1,8 +1,8 @@
 compare.graphs <- function(G1, G2) {
-  e1 <- as.data.frame(get.edges(G1, E(G1)))
-  e1[ ,3] <- edge.attributes(G1)
-  e2 <- as.data.frame(get.edges(G2, E(G2)))
-  e2[ ,3] <- edge.attributes(G2)
+  e1 <- as.data.frame(igraph::get.edges(G1, igraph::E(G1)))
+  e1[ ,3] <- igraph::edge.attributes(G1)
+  e2 <- as.data.frame(igraph::get.edges(G2, igraph::E(G2)))
+  e2[ ,3] <- igraph::edge.attributes(G2)
   n1 <- nrow(e1)
   n2 <- nrow(e2)
   if (n1 != n2) return(FALSE)
@@ -10,6 +10,6 @@ compare.graphs <- function(G1, G2) {
   if (ncol(e2) == 2) e2$description <- "O"
   e1[which(is.na(e1[,3])), 3] <- "O"
   e2[which(is.na(e2[,3])), 3] <- "O"
-  if (all(duplicated(rbind(e1,e2))[(n1+1):(2*n1)])) return(TRUE)
+  if (all(duplicated(rbind(e1, e2))[(n1+1):(2*n1)])) return(TRUE)
   return(FALSE)
 }
\ No newline at end of file
