@@ -1,8 +1,8 @@
-parse.expression <- function(P, topo, G.adj, G, G.obs) {
+parse.expression <- function(P, topo, G.unobs, G, G.obs) {
   if (P$fraction) {
     P <- cancel.out(P)
     if (P$fraction) {
-      P$den <- parse.expression(P$den, topo, G.adj, G, G.obs)
+      P$den <- parse.expression(P$den, topo, G.unobs, G, G.obs)
       if (length(P$den) == 0) {
         sum_p <- P$sumset
         P <- P$num
@@ -23,7 +23,7 @@ parse.expression <- function(P, topo, G.adj, G, G.obs) {
           P$sumset <- setdiff(P$sumset, nodep) %ts% topo
         }
       }
-      P$num <- parse.expression(P$num, topo, G.adj, G, G.obs)
+      P$num <- parse.expression(P$num, topo, G.unobs, G, G.obs)
       P <- cancel.out(P)
     }
     return(P)
@@ -35,7 +35,7 @@ parse.expression <- function(P, topo, G.adj, G, G.obs) {
       parse_children <- P$children[non_atomic]
       P$children <- P$children[!non_atomic]
       for (i in 1:length(parse_children)) {
-        P.parse <- parse.expression(parse_children[[i]], topo, G.adj, G, G.obs)
+        P.parse <- parse.expression(parse_children[[i]], topo, G.unobs, G, G.obs)
         if (!is.null(P.parse$collapse)) {
           P$children <- c(P$children, P.parse$children)
         } else {
@@ -58,7 +58,7 @@ parse.expression <- function(P, topo, G.adj, G, G.obs) {
     ord.sum <- order(sapply(P$sumset, FUN = function(x) which(topo == x)), decreasing = TRUE)
     P$children <- P$children[ord.children]
     P$sumset <- P$sumset[ord.sum]
-    P <- simplify(P, topo, G.adj, G, G.obs)
+    P <- simplify(P, topo, G.unobs, G, G.obs)
     if (length(P$children) == 0) return(NULL)
   }
   P.parse <- probability(product = TRUE, children = list())
@@ -82,7 +82,7 @@ parse.expression <- function(P, topo, G.adj, G, G.obs) {
         sum_p <- P$sumset
         P <- P$children[[1]]
         P$sumset <- union(sum_p, P$sumset) %ts% topo
-        P <- parse.expression(P, topo, G.adj, G, G.obs)
+        P <- parse.expression(P, topo, G.unobs, G, G.obs)
       }
     }
     if (length(P$children) > 0) P.parse$children[[j + 1]] <- P
